#!/bin/sh

# Cada archivo de color tiene cuatro líneas
# 1- Colores habituales
# 2- Colores para ventanas enfocadas y otros elementos activos
# 3- Color del fondo del escritorio
# 4- Colores especiales para resaltar el reloj --en mi configuración,
#	el fichero /rbar/time--

if [[ -e ~/.wmii/colores/$1 && $1 != "" ]]; then
	coloresbasicos=`sed -n 1p ~/.wmii/colores/$1` 
	colorfondo=`sed -n 3p ~/.wmii/colores/$1`
	coloresfoco=`sed -n 2p ~/.wmii/colores/$1` 
	coloresreloj=`sed -n 4p ~/.wmii/colores/$1` 
	echo "focuscolors $coloresfoco" | wmiir write /ctl
	echo "normcolors $coloresbasicos" | wmiir write /ctl
	for i in `wmiir ls /rbar`; do
		if [[ $i == "time" ]]; then
			echo $coloresreloj | wmiir write "/rbar/$i"
		else
			echo $coloresbasicos | wmiir write "/rbar/$i"
		fi
	done
	rm ~/.wmii/coloractual
	ln -s ~/.wmii/colores/$1 ~/.wmii/coloractual

	# Colorear las etiquetas de los "tags"
	for i in `wmiir ls /lbar`; do
		echo "$coloresbasicos $i" | wmiir write /lbar/$i
	done
	actual=`wmiir read /tag/sel/ctl | head -1`
	echo "$coloresfoco $actual" | wmiir write /lbar/$actual

	#fondo
	xsetroot -solid "$colorfondo"
else
	if [[ $1 != "" ]]; then
		echo "No existe el fichero ~/.wmii/colores/$1"
	else
		echo "No se especificó archivo"
	fi
fi
