#/bin/sh

cuenta=1
while [ 1 ]; do
	sed -n "$cuenta"p /tmp/tiempo | iconv -f ISO8859-15 -t UTF-8 > /tmp/orajwmii
	cuenta=$(($cuenta+1))
	if [[ $cuenta -eq 7 ]]; then
		# Sólo hay 6 líneas en el fichero /tmp/tiempo
		cuenta=1
	fi
	sleep 20
done
